<?php declare(strict_types=1);

namespace EuKit\Base\Services;

use EuKit\Base\Interfaces\ThemeServiceStartup;
use Infomaker\Everyware\Base\Sidebars;

/**
 * Class SidebarServiceStartup
 * @package EuKit\Base\Services
 */
class SidebarServiceStartup implements ThemeServiceStartup
{
    /**
     * @var array
     */
    private $registeredSidebars;

    public function registerSidebar(string $id, array $options): void
    {
        $this->registeredSidebars[$id] = $options;
    }

    public function registerSidebars(array $sidebars): void
    {
        foreach ($sidebars as $id => $options) {
            $this->registerSidebar($id, $options);
        }
    }

    public function setup(): void
    {
        $this->registerSidebars([
            'ew-footer-1' => [
                'name' => __('Footer 1', 'ewkit'),
                'description' => __('Container that is rendered just before the page footer.', 'ewkit'),
                'before_widget' => '<div class="footer-container__widget">',
                'after_widget' => '</div>',
            ],
            'ew-footer-2' => [
                'name' => __('Footer 2', 'ewkit'),
                'description' => __('Container that is rendered in the footer.', 'ewkit'),
                'before_widget' => '<div class="footer-container__widget">',
                'after_widget' => '</div>',
            ],
            'ew-footer-3' => [
                'name' => __('Footer 3', 'ewkit'),
                'description' => __('Container that is rendered in the footer.', 'ewkit'),
                'before_widget' => '<div class="footer-container__widget">',
                'after_widget' => '</div>',
            ],
            'ew-footer-4' => [
                'name' => __('Footer 4', 'ewkit'),
                'description' => __('Container that is rendered in the footer.', 'ewkit'),
                'before_widget' => '<div class="footer-container__widget">',
                'after_widget' => '</div>',
            ],
            'ew-sidebar' => [
                'name' => __('Sidebar', 'ewkit'),
                'description' => __('Container for sidebar.', 'ewkit'),
                'before_widget' => '<div class="sidebar-container__widget">',
                'after_widget' => '</div>',
            ],
            'ew-below-article' => [
                'name' => __('Below article', 'ewkit'),
                'description' => __('Container below article.', 'ewkit'),
                'before_widget' => '<div class="row below-article-container__widget">',
                'after_widget' => '</div>',
            ],

            // Static Page sidebars
            'static-page-sidebar' => [
                'name' => __('Static page sidebar', 'ewkit'),
                'description' => __('Container on the side of a static page.', 'ewkit'),
                'before_widget' => '<div class="static-page-sidebar__widget">',
                'after_widget' => '</div>',
            ],
            'static-page-panorama' => [
                'name' => __('Static page panorama', 'ewkit'),
                'description' => __('Container on the top of a static page.', 'ewkit'),
                'before_widget' => '<div class="static-page-panorama__widget">',
                'after_widget' => '</div>',
            ],

            // Concept Page sidebars
            'concept-page-sidebar' => [
                'name' => __('Concept page sidebar', 'ewkit'),
                'description' => __('Container on the side of the concept page.', 'ewkit'),
                'before_widget' => '<div class="concept-page-sidebar__widget">',
                'after_widget' => '</div>',
            ],
            'concept-page-panorama' => [
                'name' => __('Concept page panorama', 'ewkit'),
                'description' => __('Container on the top of the concept page.', 'ewkit'),
                'before_widget' => '<div class="concept-page-panorama__widget">',
                'after_widget' => '</div>',
            ]
        ]);

        foreach ($this->registeredSidebars as $id => $sidebar) {
            Sidebars::register($id, $sidebar);
        }
    }
}
